==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/fr/lang.php <==
<?php
/**
 * french language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Sébastien Bauer <sebastien.bauer@advalvas.be>
 * @author Antoine Fixary <antoine.fixary@freesbee.fr>
 * @author cumulus <pta-n56@myamail.com>
 * @author Gwenn Gueguen <contact@demisel.net>
 * @author Guy Brand <gb@isis.u-strasbg.fr>
 * @author Fabien Chabreuil <fabien@integralpersonality.com>
 * @author Stéphane Chamberland <stephane.chamberland@ec.gc.ca>
 * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
 * @author gb@isis.u-strasbg.fr
 */
$lang['admin_acl']             = 'Gestion de la liste des contrôles d\'accès (ACL)';
$lang['acl_group']             = 'Groupe';
$lang['acl_user']              = 'Utilisateur';
$lang['acl_perms']             = 'Permission pour';
$lang['page']                  = 'Page';
$lang['namespace']             = 'Catégorie';
$lang['btn_select']            = 'Sélectionner';
$lang['p_user_id']             = 'Permissions actuelles de l\'utilisateur <b class="acluser">%s</b> sur la page <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Permissions actuelles de l\'utilisateur <b class="acluser">%s</b> sur la catégorie <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Permissions actuelles des membres du groupe <b class="aclgroup">%s</b> sur la page <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Permissions actuelles des membres du groupe <b class="aclgroup">%s</b> sur la catégorie <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Saisissez un nom <b>d\'utilisateur ou de groupe</b> dans le formulaire ci-dessus pour afficher ou éditer les permissions relatives à la page <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Saisissez un nom <b>d\'utilisateur ou de groupe</b> dans le formulaire ci-dessous pour afficher ou éditer les permissions relatives à la catégorie <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Note : Ces permissions n\'ont pas été explicitement fixées mais sont héritées d\'autres groupes ou catégories supérieures.';
$lang['p_isadmin']             = 'Note : Le groupe ou l\'utilisateur sélectionné dispose de toutes les permissions car il est paramétré en tant que superutilisateur.';
$lang['current']               = 'ACL actuelles';
$lang['where']                 = 'Page/Catégorie';
$lang['who']                   = 'Utilisateur/Groupe';
$lang['perm']                  = 'Permissions';
$lang['acl_perm0']             = 'Aucune';
$lang['acl_perm1']             = 'Lecture';
$lang['acl_perm2']             = 'Écriture';
$lang['acl_perm4']             = 'Création';
$lang['acl_perm8']             = 'Télécharger';
$lang['acl_perm16']            = 'Effacer';
$lang['acl_new']               = 'Ajouter une nouvelle entrée';
$lang['acl_mod']               = 'Modifier l\'entrée';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/fr/lang.php <==
<?php
/**
 * french language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Sébastien Bauer <sebastien.bauer@advalvas.be>
 * @author Antoine Fixary <antoine.fixary@freesbee.fr>
 * @author cumulus <pta-n56@myamail.com>
 * @author Gwenn Gueguen <contact@demisel.net>
 * @author Guy Brand <gb@isis.u-strasbg.fr>
 * @author Fabien Chabreuil <fabien@integralpersonality.com>
 * @author Stéphane Chamberland <stephane.chamberland@ec.gc.ca>
 * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
 * @author gb@isis.u-strasbg.fr
 * @author stephane.gully@gmail.com
 * @author Guillaume Turri <guillaume.turri@gmail.com>
 */
$lang['admin_acl']             = 'Gestion de la liste des contrôles d\'accès (ACL)';
$lang['acl_group']             = 'Groupe';
$lang['acl_user']              = 'Utilisateur';
$lang['acl_perms']             = 'Permission pour';
$lang['page']                  = 'Page';
$lang['namespace']             = 'Catégorie';
$lang['btn_select']            = 'Sélectionner';
$lang['p_user_id']             = 'Permissions actuelles de l\'utilisateur <b class="acluser">%s</b> sur la page <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Permissions actuelles de l\'utilisateur <b class="acluser">%s</b> sur la catégorie <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Permissions actuelles des membres du groupe <b class="aclgroup">%s</b> sur la page <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Permissions actuelles des membres du groupe <b class="aclgroup">%s</b> sur la catégorie <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Saisissez un nom <b>d\'utilisateur ou de groupe</b> dans le formulaire ci-dessus pour afficher ou éditer les permissions relatives à la page <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Saisissez un nom <b>d\'utilisateur ou de groupe</b> dans le formulaire ci-dessous pour afficher ou éditer les permissions relatives à la catégorie <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Note : Ces permissions n\'ont pas été explicitement fixées mais sont héritées d\'autres groupes ou catégories supérieures.';
$lang['p_isadmin']             = 'Note : Le groupe ou l\'utilisateur sélectionné dispose de toutes les permissions car il est paramétré en tant que superutilisateur.';
$lang['p_include']             = 'Les permissions les plus élevées induisent les plus faibles. Création, Télécharger, et Effacer, ne s\'appliquent qu\'aux catégories ; pas aux pages';
$lang['current']               = 'ACL actuelles';
$lang['where']                 = 'Page/Catégorie';
$lang['who']                   = 'Utilisateur/Groupe';
$lang['perm']                  = 'Permissions';
$lang['acl_perm0']             = 'Aucune';
$lang['acl_perm1']             = 'Lecture';
$lang['acl_perm2']             = 'Écriture';
$lang['acl_perm4']             = 'Création';
$lang['acl_perm8']             = 'Télécharger';
$lang['acl_perm16']            = 'Effacer';
$lang['acl_new']               = 'Ajouter une nouvelle entrée';
$lang['acl_mod']               = 'Modifier l\'entrée';
